class Seasons:
    crimson_heist = "crimson_heist"
    neon_dawn = "neon_dawn"
    shadow_legacy = "shadow_legacy"
    steel_wave = "steel_wave"
    void_edge = "void_edge"
    shifting_tides = "shifting_tides"
    ember_rise = "ember_rise"
    phantom_sight = "phantom_sight"
    burnt_horizon = "burnt_horizon"
    wind_bastion = "wind_bastion"
    grim_sky = "grim_sky"
    para_bellum = "para_bellum"
    chimera = "chimera"
    white_noise = "white_noise"
    blood_orchid = "blood_orchid"
    health = "health"
